@@ -16,20 +16,18 @@ from flask_wtf.csrf import CSRFProtect
 app = Flask(
     import_name=__name__,
     template_folder="templates",
-    # TODO @Note: let nginx or other more resourceful Load Balancer
+    # @Note: let nginx or other more resourceful Load Balancer
     # serve static content within this folder.
     static_folder="static",
 )
 
 app.jinja_env.auto_reload = app.config["DEBUG"]
 
-if app.config["ENV"] == "production":
-    app.config.from_object("xtcryptosignals.client.config.ConfigProduction")
-elif app.config["ENV"] == "development":
-    app.config.from_object("xtcryptosignals.client.config.ConfigDevelopment")
-elif app.config["ENV"] == "docker":
-    app.config.from_object("xtcryptosignals.client.config.ConfigDocker")
-else:
+try:
+    app.config.from_object(
+        f"xtcryptosignals.client.config.Config{app.config['ENV'].title()}"
+    )
+except ImportError:
     raise ValueError("Unknown FLASK_ENV")
 
 app.config.from_envvar("SETTINGS_APP")
