@@ -15,6 +15,7 @@ from flask import (
     current_app,
     g,
 )
+from flask_login import login_required
 from xtcryptosignals.client import service
 from xtcryptosignals import __version__
 from xtcryptosignals.client.utils import validate_args
@@ -62,7 +63,7 @@ def context_processor():
         current_year=datetime.utcnow().year,
         frequencies=g.HISTORY_FREQUENCY,
         pairs=get_pairs(g.SYMBOLS_PER_EXCHANGE),
-        tokens=get_coin_tokens(g.SYMBOLS_PER_EXCHANGE),
+        tokens=get_coin_tokens(g.SYMBOLS_PER_EXCHANGE, show_all=True),
     )
 
 
@@ -77,6 +78,31 @@ def ticker(frequency):
     )
 
 
+@bp.route("/ticker/tokens/<frequency>")
+@validate_args()
+def ticker_coins_or_tokens(frequency):
+    coins_or_tokens_favourites, _ = service.get_coins_or_tokens_reference()
+    return dict(
+        template_name_or_list="ticker/ticker-coins-or-tokens.html",
+        coins_or_tokens_favourites=coins_or_tokens_favourites,
+        attributes=_COLUMN_ATTRIBUTES,
+        frequency=frequency,
+    )
+
+
+@bp.route("/ticker/favourites/<frequency>")
+@login_required
+@validate_args()
+def favourites(frequency):
+    coins_or_tokens_favourites, _ = service.get_coins_or_tokens_favourites()
+    return dict(
+        template_name_or_list="ticker/ticker-favourites.html",
+        coins_or_tokens_favourites=coins_or_tokens_favourites,
+        attributes=_COLUMN_ATTRIBUTES,
+        frequency=frequency,
+    )
+
+
 @bp.route("/ticker/<pair>/<frequency>")
 @validate_args()
 def pair_frequency(pair, frequency):
@@ -121,7 +147,7 @@ def token_frequency(coin_or_token, frequency):
     project = [x for x in projects if x["coin_or_token"] == coin_or_token][0]
     project_twitter, _ = service.get_project_last_tweet(project["_id"])
     return dict(
-        template_name_or_list="ticker/token_frequency.html",
+        template_name_or_list="ticker/token-frequency.html",
         symbols_per_exchange=x,
         attributes={**{"price_usdt": "Price USDT"}, **_COLUMN_ATTRIBUTES},
         frequency=frequency,
