@@ -11,18 +11,17 @@ __email__ = "pjmlantunes@gmail.com"
 from flask import Flask
 from flask_session import Session
 from flask_socketio import SocketIO
+from flasgger import Swagger
 from mongoengine import connect
 
 
 app = Flask(__name__)
 
-if app.config["ENV"] == "production":
-    app.config.from_object("xtcryptosignals.server.config.ConfigProduction")
-elif app.config["ENV"] == "development":
-    app.config.from_object("xtcryptosignals.server.config.ConfigDevelopment")
-elif app.config["ENV"] == "docker":
-    app.config.from_object("xtcryptosignals.client.config.ConfigDocker")
-else:
+try:
+    app.config.from_object(
+        f"xtcryptosignals.server.config.Config{app.config['ENV'].title()}"
+    )
+except ImportError:
     raise ValueError("Unknown FLASK_ENV")
 
 app.config.from_envvar("SETTINGS_APP")
@@ -79,4 +78,7 @@ def create_app():
         cors_allowed_origins=app.config["CORS_ALLOWED_ORIGINS"],
     )
 
+    if app.config["SWAGGER"]:
+        Swagger(app)
+
     return app
