@@ -19,3 +19,7 @@ class Contact(DocumentValidation):
     email = EmailField(required=True)
     reason = StringField(required=True, choices=("question", "bug",))
     message = StringField(required=True)
+
+    meta = {
+        "collection": "contact",
+    }
