@@ -9,6 +9,7 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 import redis
+import json
 from xtcryptosignals.server.api.transactions.models import Transaction
 from xtcryptosignals.common.utils import get_coin_tokens
 from xtcryptosignals.tasks import settings as s
@@ -23,10 +24,7 @@ def get_exchange_for(coin_token):
 
 def _get_percentage(x, y):
     try:
-        if x >= y:
-            t = 100 - ((y * 100) / x)
-        else:
-            t = -(100 - ((x * 100) / y))
+        t = -(100 - ((x * 100) / y))
         return round(t, 2)
     except ZeroDivisionError:
         return 0.0
@@ -38,7 +36,9 @@ def _get_current_price(exchange, coin_token):
         symbol=coin_token + exchange["pair"],
         frequency=s.HISTORY_FREQUENCY[0],
     )
-    price = float(red.get(key))
+    ser_row = red.get(key)
+    deser_row = json.loads(ser_row)
+    price = float(deser_row["price"])
 
     if exchange["pair"] != "USDT":
         key = s.REDIS_KEY_TICKER.format(
@@ -46,7 +46,9 @@ def _get_current_price(exchange, coin_token):
             symbol=exchange["pair"] + "USDT",
             frequency=s.HISTORY_FREQUENCY[0],
         )
-        price_usdt = float(red.get(key))
+        ser_row = red.get(key)
+        deser_row = json.loads(ser_row)
+        price_usdt = float(deser_row["price"])
 
         price = price * price_usdt
 
@@ -101,7 +103,7 @@ def portfolio(auth):
         try:
             current_price = _get_current_price(exchange, coin_token)
         except TypeError:
-            # pair is not stored in Redis - most likely Exchange API is
+            # @Note: pair is not stored in Redis - most likely Exchange API is
             # failing
             # TODO: Still display this row in red in UI
             continue
@@ -127,12 +129,14 @@ def portfolio(auth):
         total_value += total_units * current_price
 
     btc_price = _portfolio["coin_tokens"]["BTC"]["current_price"]
+    eth_price = _portfolio["coin_tokens"]["ETH"]["current_price"]
 
     _portfolio.update(
         total_paid=round(total_paid, 2),
         total_value=round(total_value, 2),
         total_position=_get_percentage(total_value, total_paid),
         total_in_btc=round(total_value / btc_price, 2),
+        total_in_eth=round(total_value / eth_price, 2),
     )
 
     _set_share_per_coin_token(_portfolio)
