@@ -9,6 +9,7 @@ __email__ = "pjmlantunes@gmail.com"
 
 
 import redis
+import json
 from marshmallow import Schema, fields
 from xtcryptosignals.tasks import settings as s
 
@@ -22,16 +23,17 @@ class BaseSchema(Schema):
 
     def post_load(self, data):
         data_symbol = data["symbol"][-3:]
-        if data_symbol in ("ETH", "BTC"):
-            price = red.get(
-                s.REDIS_KEY_TICKER.format(
-                    source=s.BINANCE,
-                    symbol=data_symbol + "USDT",
-                    frequency=s.HISTORY_FREQUENCY[0],
-                )
+        if data_symbol in s.COIN_OR_TOKEN_REFERENCE[:2]:
+            key = s.REDIS_KEY_TICKER.format(
+                source=s.BINANCE,
+                symbol=data_symbol + "USDT",
+                frequency=s.HISTORY_FREQUENCY[0],
             )
-            if not price:
+            ser_row = red.get(key)
+            if not ser_row:
                 return
+            deser_row = json.loads(ser_row)
+            price = deser_row["price"]
             data["price_usdt"] = data["price"] * float(price)
-        elif data["symbol"][-4:] == "USDT":
+        elif data_symbol in s.COIN_OR_TOKEN_REFERENCE[2:]:
             data["price_usdt"] = data["price"]
